@@ -1,27 +1,39 @@
 # coding: utf-8
-from __future__ import absolute_import
-from __future__ import unicode_literals
+from abc import (
+    ABCMeta,
+    abstractmethod,
+)
+from copy import (
+    deepcopy,
+)
+from itertools import (
+    chain,
+    count,
+)
 
-from abc import ABCMeta
-from abc import abstractmethod
-from itertools import chain
-from itertools import count
+from six.moves import (
+    http_client,
+    map,
+    range,
+)
 
-from six import iteritems
-from six import text_type
-from six import with_metaclass
-from six.moves import http_client
-from six.moves import map
-from six.moves import range
-
-from m3_gar_client.backends.m3_rest_gar.proxy.server import server
-from m3_gar_client.constants import GAR_HIERARCHY_MUN, DEFAULT_PAGE_LIMIT
-from m3_gar_client.constants import GAR_LEVELS_PLACE
-from m3_gar_client.constants import GAR_LEVELS_STREET
-from m3_gar_client.data import AddressObject
-from m3_gar_client.data import House
-from m3_gar_client.data import ObjectMapper
-from m3_gar_client.utils import cached_property
+from m3_gar_client.backends.m3_rest_gar.proxy.server import (
+    server,
+)
+from m3_gar_client.constants import (
+    DEFAULT_PAGE_LIMIT,
+    GAR_HIERARCHY_MUN,
+    GAR_LEVELS_PLACE,
+    GAR_LEVELS_STREET,
+)
+from m3_gar_client.data import (
+    AddressObject,
+    House,
+    ObjectMapper,
+)
+from m3_gar_client.utils import (
+    cached_property,
+)
 
 
 # -----------------------------------------------------------------------------
@@ -266,7 +278,10 @@ class LoaderBase(with_metaclass(ABCMeta, object)):
 
         :rtype: generator
         """
-        from django.conf import settings
+        from django.conf import (
+            settings,
+        )
+
         # Значение PAGE_LIMIT по умолчанию 5. С большим PAGE_LIMIT можно заддосить ГАР
         page_limit = settings.GAR.get('PAGE_LIMIT', DEFAULT_PAGE_LIMIT)
 
@@ -448,7 +463,9 @@ class PlaceLoader(AddressObjectLoaderBase):
         return object_data['level'], object_data['fullName'] or ''
 
     def load_raw(self, page=None):
-        from django.conf import settings
+        from django.conf import (
+            settings,
+        )
 
         def get_page_counter():
             if page is None:
@@ -491,24 +508,30 @@ class PlaceLoader(AddressObjectLoaderBase):
                             break
 
             else:
-                # Займемся поиском родителей
-                params = self._get_params()
+                # Переопределим родителей, чтобы не плодить их для каждого параметра фильтрации
+                _parent_ids = deepcopy(parent_ids) or set([None])
+                parent_ids = set()
 
-                for page_number in count(start=1):
-                    #  Не ограничиваем поиск колчиество страницы, чтобы не
-                    #  потерять результаты
-                    drf_data = self._load_page(params, page_number)
+                for _parent_id in _parent_ids:
+                    self._parent_id = _parent_id
 
-                    if drf_data:
-                        for drf_object_data in drf_data['results']:
-                            parent_ids.add(drf_object_data['objectguid'])
+                    # Займемся поиском родителей
+                    params = self._get_params()
 
-                        if not drf_data['next']:
+                    for page_number in count(start=1):
+                        #  Не ограничиваем поиск количеством страниц, чтобы не потерять результаты
+                        drf_data = self._load_page(params, page_number)
+
+                        if drf_data:
+                            for drf_object_data in drf_data['results']:
+                                parent_ids.add(drf_object_data['objectguid'])
+
+                            if not drf_data['next']:
+                                break
+
+                        else:
                             break
 
-                    else:
-                        break
-
 
 class StreetLoader(AddressObjectLoaderBase):
     """
