@@ -270,7 +270,8 @@ Ext.m3.gar.AddressFields = Ext.extend(Ext.Component, {
             result.push(
                 this.houseNumberField,
                 this.buildingNumberField,
-                this.structureNumberField
+                this.structureNumberField,
+                this.houseTypeField,
             );
         }
 
@@ -353,7 +354,8 @@ Ext.m3.gar.AddressFields = Ext.extend(Ext.Component, {
                 !this.houseNumberField.getValue() &&
                 !this.buildingNumberField.getValue() &&
                 !this.structureNumberField.getValue() &&
-                !this.houseIDField.getValue()
+                !this.houseIDField.getValue() &&
+                !this.hasHouseTypeField.getValue()
             );
         }
     },
@@ -672,6 +674,8 @@ Ext.m3.gar.AddressFields = Ext.extend(Ext.Component, {
 
         this.houseIDField.setValue(record.get('objectId'));
 
+        this.houseTypeField.setValue(record.get('houseType'))
+
         if (record.get('houseNumber')) {
             this.houseNumberField.setValue(record.get('houseNumber'))
             this.flatNumberField.setReadOnly(false);
@@ -803,7 +807,7 @@ Ext.m3.gar.AddressFields = Ext.extend(Ext.Component, {
                 }
                 else {
                     addressParts.push(
-                   'д.' + this.houseNumberField.getValue()
+                   this.houseTypeField.getValue() + this.houseNumberField.getValue()
                     );
                 }
             }
@@ -997,7 +1001,7 @@ Ext.m3.gar.AddressViewBase = Ext.extend(Ext.Container, {
                     'уч.{steadNumber}',
                 '</tpl>',
                 '<tpl if="houseNumber">',
-                    'д.{houseNumber}',
+                    '{houseType}{houseNumber}',
                 '</tpl>',
                 '<tpl if="buildingNumber">',
                     ' корп.{buildingNumber}',
@@ -1141,7 +1145,8 @@ Ext.m3.gar.RowsAddressView = Ext.extend(Ext.m3.gar.AddressViewBase, {
             this.houseFieldContainer,
             this.buildingFieldContainer,
             this.structureFieldContainer,
-            this.fields.houseIDField
+            this.fields.houseIDField,
+            this.fields.houseTypeField,
         );
     },
 
